@@ -28,8 +28,8 @@ const ignore = [
 
 async function checkFile(file) {
   if (
-    extensions.some((e) => file.endsWith(e)) &&
-    !ignore.some((i) => file.includes(`/${i}/`) || path.basename(file) == i)
+    extensions.some((e) => file.endsWith(e))
+    && !ignore.some((i) => file.includes(`/${i}/`) || path.basename(file) == i)
   ) {
     const fileStream = fs.createReadStream(file)
     const rl = readline.createInterface({
@@ -42,11 +42,11 @@ async function checkFile(file) {
     for await (let line of rl) {
       // ignore empty lines, allow shebang and bundler license
       if (
-        line.length === 0 ||
-        line.startsWith('#!') ||
-        line.startsWith('// swift-tools-version:') ||
-        line === bundlerLicense ||
-        line === denoLicense
+        line.length === 0
+        || line.startsWith('#!')
+        || line.startsWith('// swift-tools-version:')
+        || line === bundlerLicense
+        || line === denoLicense
       ) {
         continue
       }
