@@ -13,7 +13,7 @@ mod settings;
 mod updater_bundle;
 mod windows;
 
-use tauri_utils::display_path;
+use tauri_utils::{display_path, platform::Target as TargetPlatform};
 
 pub use self::{
   category::AppCategory,
@@ -48,19 +48,14 @@ pub fn bundle_project(settings: &Settings) -> crate::Result<Vec<Bundle>> {
 
   package_types.sort_by_key(|a| a.priority());
 
-  let target_os = settings
-    .target()
-    .split('-')
-    .nth(2)
-    .unwrap_or(std::env::consts::OS)
-    .replace("darwin", "macos");
+  let target_os = settings.target_platform();
 
-  if target_os != std::env::consts::OS {
+  if *target_os != TargetPlatform::current() {
     log::warn!("Cross-platform compilation is experimental and does not support all features. Please use a matching host system for full compatibility.");
   }
 
   // Sign windows binaries before the bundling step in case neither wix and nsis bundles are enabled
-  if target_os == "windows" {
+  if matches!(target_os, TargetPlatform::Windows) {
     if settings.can_sign() {
       for bin in settings.binaries() {
         let bin_path = settings.binary_path(bin);
