@@ -177,7 +177,7 @@ impl ResourceDirectory {
       directories.push_str(wix_string.as_str());
     }
     let wix_string = if self.name.is_empty() {
-      format!("{}{}", files, directories)
+      format!("{files}{directories}")
     } else {
       format!(
         r#"<Directory Id="I{id}" Name="{name}">{files}{directories}</Directory>"#,
@@ -221,8 +221,7 @@ fn app_installer_output_path(
     Arch::AArch64 => "arm64",
     target => {
       return Err(crate::Error::ArchError(format!(
-        "Unsupported architecture: {:?}",
-        target
+        "Unsupported architecture: {target:?}"
       )))
     }
   };
@@ -352,8 +351,7 @@ fn run_candle(
     Arch::AArch64 => "arm64",
     target => {
       return Err(crate::Error::ArchError(format!(
-        "unsupported architecture: {:?}",
-        target
+        "unsupported architecture: {target:?}"
       )))
     }
   };
@@ -443,8 +441,7 @@ pub fn build_wix_app_installer(
     Arch::AArch64 => "arm64",
     target => {
       return Err(crate::Error::ArchError(format!(
-        "unsupported architecture: {:?}",
-        target
+        "unsupported architecture: {target:?}"
       )))
     }
   };
@@ -475,7 +472,7 @@ pub fn build_wix_app_installer(
   // when we're performing code signing, we'll sign some WiX DLLs, so we make a local copy
   let wix_toolset_path = if settings.can_sign() {
     let wix_path = output_path.join("wix");
-    crate::utils::fs_utils::copy_dir(&wix_toolset_path, &wix_path)
+    crate::utils::fs_utils::copy_dir(wix_toolset_path, &wix_path)
       .context("failed to copy wix directory")?;
     wix_path
   } else {
@@ -790,7 +787,7 @@ pub fn build_wix_app_installer(
   // sign default extensions
   if settings.can_sign() {
     for path in &fragment_extensions {
-      try_sign(&path, settings)?;
+      try_sign(path, settings)?;
     }
   }
 
@@ -845,7 +842,7 @@ pub fn build_wix_app_installer(
 
     let locale_contents = locale_contents.replace(
       "</WixLocalization>",
-      &format!("{}</WixLocalization>", unset_locale_strings),
+      &format!("{unset_locale_strings}</WixLocalization>"),
     );
     let locale_path = output_path.join("locale.wxl");
     {
