@@ -135,6 +135,7 @@ const PLUGINS: &[(&str, &[(&str, bool)])] = &[
       ("set_webview_size", false),
       ("set_webview_position", false),
       ("set_webview_focus", false),
+      ("set_webview_auto_resize", false),
       ("set_webview_zoom", false),
       ("webview_hide", false),
       ("webview_show", false),
@@ -349,7 +350,7 @@ fn main() {
   }
 
   let permissions = define_permissions(&out_dir);
-  tauri_utils::acl::build::generate_allowed_commands(&out_dir, permissions).unwrap();
+  tauri_utils::acl::build::generate_allowed_commands(&out_dir, None, permissions).unwrap();
 }
 
 const LICENSE_HEADER: &str = r"# Copyright 2019-2024 Tauri Programme within The Commons Conservancy
@@ -392,12 +393,12 @@ fn define_permissions(
     };
 
     let default_toml = format!(
-      r###"{LICENSE_HEADER}# Automatically generated - DO NOT EDIT!
+      r#"{LICENSE_HEADER}# Automatically generated - DO NOT EDIT!
 
 [default]
 description = "Default permissions for the plugin{all_enable_by_default}."
 permissions = [{default_permissions}]
-"###,
+"#,
     );
 
     let out_path = autogenerated.join("default.toml");
