@@ -7,7 +7,7 @@
 pub(crate) mod plugin;
 
 use tauri_runtime::{
-  dpi::{PhysicalPosition, PhysicalSize},
+  dpi::{PhysicalPosition, PhysicalRect, PhysicalSize},
   webview::PendingWebview,
 };
 pub use tauri_utils::{config::Color, WindowEffect as Effect, WindowEffectState as EffectState};
@@ -61,6 +61,7 @@ pub struct Monitor {
   pub(crate) name: Option<String>,
   pub(crate) size: PhysicalSize<u32>,
   pub(crate) position: PhysicalPosition<i32>,
+  pub(crate) work_area: PhysicalRect<i32, u32>,
   pub(crate) scale_factor: f64,
 }
 
@@ -70,6 +71,7 @@ impl From<RuntimeMonitor> for Monitor {
       name: monitor.name,
       size: monitor.size,
       position: monitor.position,
+      work_area: monitor.work_area,
       scale_factor: monitor.scale_factor,
     }
   }
@@ -92,6 +94,11 @@ impl Monitor {
     &self.position
   }
 
+  /// Returns the monitor's work_area.
+  pub fn work_area(&self) -> &PhysicalRect<i32, u32> {
+    &self.work_area
+  }
+
   /// Returns the scale factor that can be used to map logical pixels to physical pixels, and vice versa.
   pub fn scale_factor(&self) -> f64 {
     self.scale_factor
@@ -399,14 +406,14 @@ tauri::Builder::default()
       window.on_menu_event(handler);
     }
 
-    if let Some(effects) = self.window_effects {
-      crate::vibrancy::set_window_effects(&window, Some(effects))?;
-    }
-
     let app_manager = self.manager.manager_owned();
     let window_label = window.label().to_string();
+    let window_ = window.clone();
     // run on the main thread to fix a deadlock on webview.eval if the tracing feature is enabled
     let _ = window.run_on_main_thread(move || {
+      if let Some(effects) = self.window_effects {
+        _ = crate::vibrancy::set_window_effects(&window_, Some(effects));
+      }
       let event = crate::EventName::from_str("tauri://window-created");
       let payload = Some(crate::webview::CreatedEvent {
         label: window_label,
