@@ -16,7 +16,7 @@ function mockInternals() {
  * # Examples
  *
  * Testing setup using Vitest:
- * ```js
+ * ```ts
  * import { mockIPC, clearMocks } from "@tauri-apps/api/mocks"
  * import { invoke } from "@tauri-apps/api/core"
  *
@@ -66,36 +66,33 @@ export function mockIPC(
 ): void {
   mockInternals()
 
-  window.__TAURI_INTERNALS__.transformCallback = function transformCallback(
-    // eslint-disable-next-line @typescript-eslint/no-explicit-any
-    callback?: (response: any) => void,
+  const callbacks = new Map()
+
+  function registerCallback<T = unknown>(
+    callback?: (response: T) => void,
     once = false
   ) {
     const identifier = window.crypto.getRandomValues(new Uint32Array(1))[0]
-    const prop = `_${identifier}`
-
-    Object.defineProperty(window, prop, {
-      // eslint-disable-next-line @typescript-eslint/no-explicit-any
-      value: (result: any) => {
-        if (once) {
-          Reflect.deleteProperty(window, prop)
-        }
-
-        return callback && callback(result)
-      },
-      writable: false,
-      configurable: true
+    callbacks.set(identifier, (data: T) => {
+      if (once) {
+        unregisterCallback(identifier)
+      }
+      return callback && callback(data)
     })
-
     return identifier
   }
 
+  function unregisterCallback(id: number) {
+    callbacks.delete(id)
+  }
+
+  window.__TAURI_INTERNALS__.transformCallback = registerCallback
+
   // eslint-disable-next-line @typescript-eslint/require-await
   window.__TAURI_INTERNALS__.invoke = async function (
     cmd: string,
     args?: InvokeArgs,
-    // eslint-disable-next-line @typescript-eslint/no-unused-vars
-    options?: InvokeOptions
+    _options?: InvokeOptions
   ): Promise<unknown> {
     return cb(cmd, args)
   } as typeof invoke
